# YASARA MOVIE
# TOPIC:    1. General
# TITLE:    1.3. What's new in YASARA Structure
# REQUIRES: Dynamics 20.5.1
# AUTHOR:   Elmar Krieger & James Magahern 
# LICENSE:  GPL
# DESCRIPTION: An overview of the new features in YASARA Structure

# Change working directory to the place of this macro
# (so that we don't have to specify paths when loading stuff).
CD (MacroDir)
OnError Continue
# Don't show console and head up display
Console Off
HUD Off
# Set default parameters
CoordSys Left
Projection perspective
StickRadius 50
BallStickRadius 50,50
AtomTexture 1
Fog 100
ColorFog Black
AtomSize 100
# For this movie, the window aspect ratio is important
sizex,sizey,scale = ScreenSize
if (0.+sizey)/sizex!=0.75
  ScreenSize (0+1.3333*sizey),(sizey),(scale)
# Load background
Clear
LoadPNG tesplosion
LoadPNG tesplosion
ShowImage 1,Priority=0
explode='AutoMoveImage 2,590,290,30,20,Alpha=0,Steps=150'
hidden='X=100, Y=80, Z=1378'

#
# The Intro
#
Intro:
DelAll
UserInput Off
HideMessage
LightSource Alpha=174,Gamma=306,Ambience=085,Shadow=065
# Hide YASARA logo in the back
LoadSce yaslogo
Rotate Y=90
Pos (hidden) 
Wait 100
# Let YASARA logo fly in
ShowImage 2,Priority=0
(explode)
AutoRotate X=-2 
AutoPos X=0, Y=-57, Z=220, Steps=180, Wait=Yes
AutoRotate X=0
AutoPos Z=120,Steps=50,Wait=Yes
Wait 50
# Let Yami fly in
LoadYOb yami
PosObj Yami,(hidden)
ShowImage 2,Priority=0
(explode)
RotateObj Yami,X=180
AutoOriObj Yami,Alpha=0,Beta=180,Gamma=-25,Steps=180,Wait=No
AutoPosObj Yami,X=0,Y=3.6,Z=148,Steps=180,Wait=Yes
AutoRotateObj Yami,X=0
# Let Yami brake
z=-4.5e0
for i=1 to 50
  MoveObj Yami,Z=(z)
  Wait 1
  z=z*0.96
# Let Yami jump along the YASARA logo
AutoMoveObj 1,Z=-0.5
for jumps=1 to 4  
  for i=0 to 59
    # Place Yami
    PosObj Yami,X=0,Y=(3.6+sin (6*(i%30))*5)
    if i<30
      OriObj Yami,Gamma=(1.666*i-25)
    else
      OriObj Yami,Gamma=(-(1.666*i-50)+25)
    # Rotate Yami's antennas
    Dihedral N Res Lys,CA Res Lys,CB Res Lys,CG Res Lys Obj Yami,bound=Yes,set=(-180+6*i)
    Wait 1
AutoMoveObj 1,Z=0
AutoPosObj Yami,X=6.7,Y=-0.4,Z=50,Steps=30,Wait=No
AutoOriObj Yami,0,90,0,Steps=30
# Move the YASARA logo with Yami to the back
AutoPos X=-25.5,Y=39.5,Z=300,Steps=300,Wait=No
AutoOri Alpha=0,Beta=270,Gamma=0,Steps=300,Wait=Yes

# Let the remaining text fly in
ShowMessage "The YASARA Structure feature overview starts as soon as Yami has fallen off, use the mouse buttons to help him..."
MakeTextObj Text,Width=450,Height=220
Font Name=Arial,Height=10%,Color=303000,Spacing=2,Depth=3,DepthCol=181800
PosText 0%,90%,Justify=Left
Print "What's new in"
PosText 55%,0%,Justify=Left
Print "Structure"
PrintCon
PosObj Text,(hidden)
OriObj Text,34,-123,-250
ShowImage 2,Priority=0
(explode)
AutoPosObj Text,X=0,Y=47,Z=454,Steps=180,Wait=No
AutoOriObj Text,0,0,0,Steps=180
# Take snapshot here, Eliza!
Wait 50

# Move Yami's rotation center between his feet
MoveAtom Obj Yami,Y=24
MoveObj Yami,Y=-24

NameObj 1,Logo
# Define the YASARA logo, 'lens' is the length of the horizontal
# straight part, 'circ' is the circumference, 'gamma' is the current rotation
# angle about the Z-axis, 'omega' is the current angular velocity
logoradius=32.4e0
logoleny=logoradius*2
logolenx=189.
logolens=logolenx-logoradius*2
logocirc=logolens*2+logoradius*Pi*2
logopos()=PosObj Logo
logogamma=0.
logoomega=0.

# The current direction of Yami's jumps
yamispeed=0.
yamipos=logolens/2-50.5

score=0.

jumpsteps=30

# Let Yami jump around until he falls off
while 1
  # To adjust game speed, change loop below
  for i=0 to jumpsteps-1
    # Move Yami along
    yamipos=(yamipos+yamispeed+logocirc)%logocirc
    # Rotate the logo
    logogamma=(logogamma+logoomega+360)%360
    #logoomega=logoomega*0.95  
    # Calculate Yami's position assuming logogamma=0
    if yamipos<logolens
      posx=-logolens/2+yamipos
      posy=logoradius
      gamma=90.
    elif yamipos>=logolens+logoradius*Pi and yamipos<logocirc-logoradius*Pi
      posx=logolens/2-(yamipos-logolens-logoradius*Pi)
      posy=-logoradius
      gamma=270.
    else
      if yamipos<logolens+logoradius*Pi
        gamma=90.-180.*(yamipos-logolens)/(logoradius*Pi)
        posx=logolens/2+cos gamma*logoradius
      else
        gamma=90.+180.*(logocirc-yamipos)/(logoradius*Pi)
        posx=-logolens/2+cos gamma*logoradius
      posy=sin gamma*logoradius
    # Transform Yami's coordinates to consider the current logo angle gamma
    rotposx=posx*cos logogamma-posy*sin logogamma
    rotposy=posx*sin logogamma+posy*cos logogamma
    # Place Yami
    gamma=(gamma+logogamma+270)%360
    PosObj Yami,X=(logopos1+rotposx),Y=(logopos2+rotposy+sin (180.*i/jumpsteps)*10)
    OriObj Yami,Gamma=(gamma)
    # Orient the Logo
    OriObj Logo,Gamma=(logogamma)
    # Rotate Yami's antennas
    Dihedral N Res Lys,CA Res Lys,CB Res Lys,CG Res Lys Obj yami,bound=Yes,set=(-180.+360.*i/jumpsteps)
    # Update the Yami movement speed
    if LeftButton
      yamispeed=yamispeed-0.05
    if RightButton
      yamispeed=yamispeed+0.05
    yamispeed=yamispeed+cos (gamma+90)*0.05
    #ShowMessage 'Gamma=(0.00+gamma), Pos=(0.00+yamipos),Speed=(yamispeed)'  
    if gamma>70 and gamma<290
      break 2
    Wait 1
  # Update the logo speed depending on Yami's position
  logoomega=logoomega-rotposx*0.002
  if abs logoomega>score
    score=abs logoomega
    UnlabelAll
    LabelPar Font=Arial
    LabelAll 'Score (0+score*100)',Height=0.4,Color=000030,X=4.3,Y=3.9 
  
# Let Yami fall off
HideMessage
CenterObj Yami
AutoRotateObj Yami,1,2,3
AutoRotateObj Logo,Z=(logoomega)
AutoMoveObj Yami,Y=-2
Wait 150
DelObj Yami

# Fly through the YASARA logo
ShowImage 2,Priority=0
(explode)
AutoRotateObj Text,X=0.2,Y=0.3,Z=-0.1
AutoMoveObj Text,Z=-0.5
AutoPosObj Logo,X=-27,Y=-17.5,Z=44,Steps=400,Wait=No
AutoOriObj Logo,Alpha=90,Beta=360,Gamma=0,Steps=400
AutoMoveObj Logo,Z=-0.8
AutoMoveObj Text,Z=-1.5
Wait 150

# Move the lightsource away
for i=174. to 135. step -0.25
  LightSource Alpha=(i)
  Wait 1
LightSource 45,45,85,Shadow=65

# Introduce the various new features. Each feature can be selected individually.
Docking:
first=1
Go MainLoop

SideChains:
first=2
Go MainLoop

HBondNet:
first=3
Go MainLoop

Loops:
first=4
Go MainLoop

KBPotentials:
first=5
Go MainLoop

HomologyModeling:
first=6
Go MainLoop

Validation:
first=7
Go MainLoop

Blast:
first=8
Go MainLoop

IonSites:
first=9

# The main loop
MainLoop:
UserInput On
PointPar Radius=8,Plastic=Yes
LightSource 45,45,85,Shadow=0
HideMessage
ColorBonds Order
featurelist='docking',         'sidechains',      'hbondnet',        'loops',        'kbpotentials',
            'homologymodeling','validation',      'blast',           'ionsites'
# The scene positions to move into the webpage windows 
startposlist='90,-3.5,103',    '81,-3.5,87.5',    '30,-1.5,33',      '67,30,80',    '41,-3,25.5',
             '310,-70,80',     '60,-20,60',       '75,-3,76',        '95,5,96'
endposlist=  '24,-3.5,103,100','24,-3.5,87.5,100','-47,-1.5,33,1000','20,30,80,100','12,-3,25.5,100',
             '20,-70,80,200',  '17,-20,60,100',   '20,-3,76,100',    '27,5,96,100'
features=count featurelist
for i=first to features
  DelAll
  DelImage not 1-2
  AtomTexture 1
  feature=featurelist(i)
  # Show countdown
  MakeTextObj Text,Width=400,Height=10
  Font Name=Arial,Height=100%,Color=Yellow,Depth=3,DepthCol=808000
  PosText 50%,0%,Justify=Center
  Print 'Feature (i)/(features)'
  PosObj Text,X=140,Y=80,Z=1250
  AutoRotateObj Text,Z=0.2
  AutoPosObj Text,X=0,Y=-10,Z=-10,Steps=200,Wait=No
  # Let the webpage fly in
  img=LoadPNG (feature)
  ShowImage 2,Priority=0
  (explode)
  #ShowImage (img),-4800,-2048,9216,6912,Alpha=0,Priority=1
  ShowImage (img),-10600,-3596,18816,11008,Alpha=10,Priority=0
  AutoMoveImage (img),0,0,1024,720,Alpha=100,Steps=300,Zoom3D=Yes
  Wait 302
  ShowImage (img),0,0,1024,720,Alpha=100,Priority=1
  # Load and show the scene
  LoadSce (feature)1,Settings=Yes
  Pos (startposlist(i))
  AutoPos (endposlist(i))
  if feature=='docking'
    # =======
    # DOCKING
    # ======= 
    AutoRotate Y=0.1
    ShowButton Continue
    while 1
      for j=001 to 015
        HideRes XK2
        ShowRes Segment C(j)
        Wait 10
        if ContinueButton
          break 2
    AutoMove Z=-1
    AutoMoveImage (img),0,700,1024,720,Steps=100
    Wait ContinueButton
    AutoMoveImage (img),496,1032,32,24,Alpha=0,Steps=100
  elif feature=='sidechains'
    # =====================
    # SIDE-CHAIN PREDICTION
    # =====================
    PosObj Arrow,Z=87.5
    AutoRotate Y=0.1
    Wait ContinueButton
    AutoMoveImage (img),0,345,1024,720,Steps=100
    AutoPos 32,26.5,127,Steps=100,Wait=No
    AutoOri 0,0,0,Steps=100
    AutoRotate Y=0.1
    Wait ContinueButton
    AutoMoveImage (img),496,(345+332),32,24,Alpha=0,Steps=100
    AutoMove Z=-1
  elif feature=='hbondnet'
    # ==================================
    # HYDROGEN BONDING NETWORK OPTIMIZER
    # ==================================
    AutoPos 5,-1,82.5,Steps=100
    Center
    Wait ContinueButton
    AutoMove X=1
    # Consideration of bumps
    AutoMoveImage (img),0,(900-720),1024,720,Steps=100
    Wait 100
    ShowButton Continue
    while 1
      labellist='Original','Optimized'
      for j=1 to 2
        LoadSce hbondnet(j+1)
        Pos 3,11,53 
        Rotate Y=-5
        UnlabelAll
        LabelAll '2BNU: (labellist(j))',Height=0.5,Color=Yellow,X=3,Y=-3.3
        for k=0 to 359
          Rotate Y=(sin k*0.05)
          Wait 1
          if ContinueButton
            break 3
    # pH dependent ligand analysis
    AutoMoveImage (img),0,(1200-720),1024,720,Steps=100
    AutoPos X=80,Steps=100
    LoadSce hbondnet4
    UnLabelAll
    LabelAll '1W1T',Height=0.5,Color=Yellow,X=3,Y=-3.3
    Pos X=32,Y=24,Z=19
    AutoPos X=-10,Steps=100
    ShowButton Continue
    while 1
      for j=0 to 359
        Rotate Y=(sin j*0.05)
        Wait 1
        if ContinueButton
          break 2
    # Ambiguous ligand electron density
    AutoMoveImage (img),0,1200,1024,720,Steps=100
    AutoPos X=32,Steps=100
    LoadSce hbondnet5
    UnLabelAll
    LabelAll '1A5Z',Height=0.5,Color=Yellow,X=3,Y=-3.3
    Pos X=56,Y=3,Z=34
    AutoPos X=15,Steps=100
    ShowButton Continue
    while 1
      for j=0 to 359
        Rotate Y=(sin j*0.05)
        Wait 1
        if ContinueButton
          break 2
    AutoMoveImage (img),496,(1200+332),32,24,Alpha=0,Steps=100
    AutoMove X=1      
  elif feature=='loops' or feature=='blast'
    # =======================
    # LOOP MODELING AND BLAST
    # =======================
    Center
    AutoRotate Y=0.1
    Wait ContinueButton
    AutoMoveImage (img),0,(1038-720),1024,720,Steps=100
    Wait ContinueButton
    AutoMoveImage (img),496,(1038-720+332),32,24,Alpha=0,Steps=100
    AutoMove Z=-1
  elif feature=='kbpotentials'
    # ==========================
    # KNOWLEDGE BASED POTENTIALS
    # ==========================
    AutoOri Alpha=19,Beta=41,Gamma=33,Steps=150
    AutoRotate X=0.2
    Wait ContinueButton
    # Show 1D potential during simulation
    AutoMoveImage (img),0,(940-720),1024,720,Steps=100
    AutoRotate X=0
    AutoPosObj 1,X=17,Y=-3,Z=17,Steps=150,Wait=No
    AutoOriObj 1,Alpha=21,Beta=110,Gamma=43,Steps=150
    Cell Auto,Extension=10
    SwitchObj SimCell,Off
    ForceField Amber99,SetPar=No
    Cutoff 7.86
    Longrange None
    Boundary Wall
    TempCtrl SteepDes
    Sim On
    Wait SpeedMax<3000
    Temp 298K
    TempCtrl Rescale
    Wait ContinueButton
    Sim Off
    AutoPos X=40,Y=0,Z=30,Steps=100
    # Show 3D potential
    AutoMoveImage (img),0,(1012-720),1024,720,Steps=100
    LoadSce kbpotentials2
    Pos X=25,Y=1.5,Z=2.5
    AutoPos X=3.5,Steps=100 
    Wait ContinueButton
    AutoPos X=25,Steps=100 
    # Show dihedral angle potentials
    AutoMoveImage (img),0,(1700-720),1024,720,Steps=100
    LoadSce kbpotentials3
    Fog 50
    Pos X=80,Y=-2.5,Z=82
    AutoPos X=22,Steps=100 
    ShowButton Continue
    while 1
      for j=0 to 359
        Rotate Y=(sin j*0.1)
        Wait 1
        if ContinueButton
          break 2
    UnLabelAll
    AutoMoveImage (img),496,(1700-720+332),32,24,Alpha=0,Steps=100
    AutoMove Z=-1
  elif feature=='homologymodeling'
    # =================
    # HOMOLOGY MODELING
    # =================
    Wait ContinueButton
    AutoMoveImage (img),0,(1340-720),1024,720,Steps=100
    AutoPos Y=0,Steps=100
    AutoPos Z=26,Steps=100
    Wait ContinueButton
    AutoMoveImage (img),0,(2048-720),1024,720,Steps=100
    AutoPos Y=60,Steps=100
    Wait ContinueButton
    AutoMoveImage (img),496,(2048-720+332),32,24,Alpha=0,Steps=100
    AutoMove Z=-2
  elif feature=='validation'
    # ====================
    # STRUCTURE VALIDATION
    # ====================
    AutoRotate Y=0.1
    Wait ContinueButton
    AutoMoveImage (img),0,(990-720),1024,720,Steps=100
    AutoPos 25,-2,90,Steps=100
    for j=30 to -35 step -1
      ColorAtom GlobalY>(j),Property
      Wait 1
    if Model
      AtomTexture 8
    LabelObj All,OBJNAME,Height=2.0,Color=Yellow
    Wait ContinueButton
    AutoMoveImage (img),0,(1380-720),1024,720,Steps=100
    AutoPos X=70,Steps=100
    LoadSce validation2
    Pos 60,-2,38
    AutoPos X=15,Steps=100
    ShowButton Continue
    while 1
      for j=0 to 359
        Rotate Y=(sin j*0.05)
        Wait 1
        if ContinueButton
          break 2
    AutoMoveImage (img),496,(1380-720+332),32,24,Alpha=0,Steps=100
    AutoMove Z=-0.7
  elif feature=='ionsites'
    # ===================
    # ION SITE PREDICTION
    # ===================
    AutoRotate Y=0.2
    ShowMessage "Click the 'Continue' button to end this overview, or Options > Macro > Go to jump back to another section..."
    Wait ContinueButton
    AutoMoveImage (img),496,332,32,24,Alpha=0,Steps=100
    AutoMove Z=-1
  Wait 150
  DelImage (img)
AutoMoveImage 1,Alpha=0,Steps=100
Wait 100
HideMessage
